pub enum Source {
Keyboard,
Mouse,
Fsys,
}Expand description
acme makes a distinction between direct writes to /body and /tag vs text entering the buffer via one of the other fsys files but I’m not sure if I need that initially? As and when it looks useful I can add it.
Variants